==> value-2.9.0-beta1-sources.jar: org/immutables/value/internal/$processor$/$Generator_Parcelables.java <==
package org.immutables.value.processor;

import static org.immutables.generator.Intrinsics.*;

@java.lang.SuppressWarnings("all")
public class Generator_Parcelables extends org.immutables.value.processor.Parcelables {
public org.immutables.generator.Templates.Invokable generate() { return generate; }
private final org.immutables.generator.Templates.Invokable generate = new FragmentDispatch(1, 0);
void _t0__generate(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueType type = $cast(__.param(0));
  __.ln();
  __.dl();
  if ($if(type.isGenerateParcelable())) {
    __.dl();__.ln();
    __.out("  ");
    $(__, generateCreator, type);
    __.ln();
    __.out("  ");
    $(__, generateParcelableMethods, type);
    __.ln();
    
  }
  __.dl();__.ln();
  __.dl();
};

org.immutables.generator.Templates.Invokable generateCreator() { return generateCreator; }
private final org.immutables.generator.Templates.Invokable generateCreator = new FragmentDispatch(1, 1);
void _t1__generateCreator(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueType type = $cast(__.param(0));
  __.ln();
  __.ln();
  __.out("/** */").ln();
  __.out("public static final android.os.Parcelable.ClassLoaderCreator<");
  $(__, type.typeValue().relative());
  __.out("> CREATOR =").ln();
  __.out("    new android.os.Parcelable.ClassLoaderCreator<");
  $(__, type.typeValue().relative());
  __.out(">() {").ln();
  __.out("      public ");
  $(__, type.typeValue().relative());
  __.out(" createFromParcel(android.os.Parcel in) {").ln();
  __.out("        return createFromParcel(in, this.getClass().getClassLoader());").ln();
  __.out("      }").ln();
  __.ln();
  __.out("      @SuppressWarnings(\"unchecked\") ");
  __.dl();__.ln();
  __.out("      public ");
  $(__, type.typeValue().relative());
  __.out(" createFromParcel(android.os.Parcel in, ClassLoader classLoader) {").ln();
  __.out("        ");
  $(__, generateParcelableBuild, type);
  __.ln();
  __.out("      }").ln();
  __.ln();
  __.out("      public ");
  $(__, type.typeValue().relative());
  $(__, "[]");
  __.out(" newArray(int size) {").ln();
  __.out("        return new ");
  $(__, type.typeValue().relative());
  $(__, "[size]");
  __.out(";").ln();
  __.out("      }").ln();
  __.out("    };").ln();
  __.dl();
};

org.immutables.generator.Templates.Invokable generateParcelableMethods() { return generateParcelableMethods; }
private final org.immutables.generator.Templates.Invokable generateParcelableMethods = new FragmentDispatch(1, 2);
void _t2__generateParcelableMethods(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueType type = $cast(__.param(0));
  __.ln();
  __.ln();
  __.out("/** */").ln();
  __.out("@Override").ln();
  __.out("public int describeContents() {").ln();
  __.out("  return 0; //??").ln();
  __.out("}").ln();
  __.ln();
  __.out("/** */").ln();
  __.out("@Override").ln();
  __.out("public void writeToParcel(android.os.Parcel out, int flags) {").ln();
  __.dl();__.ln();
  __.out("  ");
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  for (final org.immutables.value.processor.meta.ValueAttribute a : $in(type.getSettableAttributes())) {
  __.dl();__.ln();
    __.dl();
    if ($if(a.isEncoding())) {
      __.dl();__.ln();
      __.out("  out.writeValue(");
      $(__, a.names.get);
      __.out("());").ln();
      } else if ($if(a.isJdkOptional())) {
      __.dl();__.ln();
      __.out("  out.writeValue(this.");
      $(__, a.name());
      __.out(");").ln();
      } else if ($if(a.isArrayType())) {
      __.dl();__.ln();
      __.out("  ");
      __.dl();
      if ($if(a.isPrimitiveElement())) {
        __.dl();__.ln();
        __.out("    ");
        __.dl();
        if ($if($(a.getElementType(), eq, "short"))) {
          __.dl();__.ln();
          __.out("  // Do something with short arrays, just for completeness").ln();
          __.out("  // copy it as int array, I dunno").ln();
          __.out("    ");
          
        } else {
          __.dl();__.ln();
          __.out("  out.write");
          $(__, toUpper, a.getElementType());
          __.out("Array(this.");
          $(__, a.name());
          __.out(");").ln();
          __.out("    ");
          
        }
        __.dl();__.ln();
        __.out("  ");
        } else if ($if($(a.getElementType(), eq, "java.lang.String"))) {
        __.dl();__.ln();
        __.out("  out.writeStringArray(this.");
        $(__, a.name());
        __.out(");").ln();
        __.out("  ");
        
      } else {
        __.dl();__.ln();
        __.out("  out.writeArray(this.");
        $(__, a.name());
        __.out(");").ln();
        __.out("  ");
        
      }
      __.dl();__.ln();
      } else if ($if(a.isStringType())) {
      __.dl();__.ln();
      __.out("  out.writeString(this.");
      $(__, a.name());
      __.out(");").ln();
      } else if ($if(a.isBoolean())) {
      __.dl();__.ln();
      __.out("  out.writeByte(this.");
      $(__, a.name());
      __.out(" ? (byte) 1 : (byte) 0);").ln();
      } else if ($if($(a.isShort(), or, a.isChar()))) {
      __.dl();__.ln();
      __.out("  out.writeInt(this.");
      $(__, a.name());
      __.out(");").ln();
      } else if ($if(a.isPrimitive())) {
      __.dl();__.ln();
      __.out("  out.write");
      $(__, toUpper, a.getType());
      __.out("(this.");
      $(__, a.name());
      __.out(");").ln();
      
    } else {
      __.dl();__.ln();
      __.out("  out.writeValue(");
      $(__, a.names.get);
      __.out("());").ln();
      __.dl();__.ln();
      
    }
    __.dl();__.ln();
    __.out("  ");
    __.dl();_it1.index++;
    _it1.first = false;
  }}
  __.dl();__.ln();
  __.out("}").ln();
  __.dl();
};

org.immutables.generator.Templates.Invokable readParcel() { return readParcel; }
private final org.immutables.generator.Templates.Invokable readParcel = new FragmentDispatch(1, 3);
void _t3__readParcel(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueAttribute a = $cast(__.param(0));
  $(__, output.trim, new org.immutables.generator.Templates.Fragment(0) {
  @Override public void run(org.immutables.generator.Templates.Invokation __) {
    __.dl();__.dl();__.ln();
    __.dl();
    if ($if(a.isEncoding())) {
      __.dl();__.ln();
      __.out("  (");
      $(__, a.getType());
      __.out(") in.readValue(classLoader)").ln();
      } else if ($if(a.isJdkOptional())) {
      __.dl();__.ln();
      __.out("  (");
      $(__, a.getWrappedElementType());
      __.out(") in.readValue(classLoader)").ln();
      } else if ($if(a.isNullable())) {
      __.dl();__.ln();
      __.out("  (");
      $(__, a.getType());
      __.out(") in.readValue(classLoader)").ln();
      } else if ($if(a.isArrayType())) {
      __.dl();__.ln();
      __.out("  ");
      __.dl();
      if ($if(a.isPrimitiveElement())) {
        __.dl();__.ln();
        __.out("    ");
        __.dl();
        if ($if($(a.getElementType(), eq, "short"))) {
          __.dl();__.ln();
          __.out("  null/* FIXME: Do something with short arrays */   ");
          __.dl();__.ln();
          __.out("    ");
          
        } else {
          __.dl();__.ln();
          __.out("      in.create");
          $(__, toUpper, a.getElementType());
          __.out("Array()").ln();
          __.out("    ");
          
        }
        __.dl();__.ln();
        __.out("  ");
        } else if ($if($(a.getElementType(), eq, "java.lang.String"))) {
        __.dl();__.ln();
        __.out("  in.createStringArray()").ln();
        __.out("  ");
        
      } else {
        __.dl();__.ln();
        __.out("  (");
        $(__, a.getType());
        __.out(") in.readArray(classLoader)").ln();
        __.out("  ");
        
      }
      __.dl();__.ln();
      } else if ($if(a.isStringType())) {
      __.dl();__.ln();
      __.out("  in.readString()").ln();
      } else if ($if(a.isBoolean())) {
      __.dl();__.ln();
      __.out("  in.readByte() != 0").ln();
      } else if ($if($(a.isShort(), or, a.isChar()))) {
      __.dl();__.ln();
      __.out("  (");
      $(__, a.getType());
      __.out(") in.readInt()").ln();
      } else if ($if(a.isPrimitive())) {
      __.dl();__.ln();
      __.out("  in.read");
      $(__, toUpper, a.getType());
      __.out("()").ln();
      
    } else {
      __.dl();__.ln();
      __.out("  null /* FIXME: read objects and complex types */").ln();
      __.out("  ");
      __.dl();__.ln();
      
    }
    __.dl();__.ln();
    __.dl();
  }});
  __.dl();
};

org.immutables.generator.Templates.Invokable generateParcelableBuild() { return generateParcelableBuild; }
private final org.immutables.generator.Templates.Invokable generateParcelableBuild = new FragmentDispatch(1, 4);
void _t4__generateParcelableBuild(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueType type = $cast(__.param(0));
  __.ln();
  __.dl();
  if ($if(type.isUseBuilder())) {
    __.dl();__.ln();
    $(__, type.typeBuilder().relative());
    __.out(" builder = ");
    $(__, castBuildStagedBuilder, type, new org.immutables.generator.Templates.Fragment(0) {
    @Override public void run(org.immutables.generator.Templates.Invokation __) {
      __.dl();$(__, type.factoryBuilder().relative());
      __.out("()");
      __.dl();
    }});
    __.out(";").ln();
    {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
    for (final org.immutables.value.processor.meta.ValueAttribute a : $in(type.getSettableAttributes())) {
    __.dl();__.ln();
      __.out("  ");
      __.dl();
      if ($if(a.isEncoding())) {
        __.dl();__.ln();
        __.out("builder.");
        $(__, renderers.builderCopyFrom(), a);
        __.out("(");
        $(__, readParcel, a);
        __.out(");").ln();
        __.out("  ");
        } else if ($if(a.isJdkOptional())) {
        __.dl();__.ln();
        {final org.immutables.value.processor.meta.ValueType type_atNullable_252233609 = $cast(type);
        __.dl();
          if ($if($(type_atNullable_252233609, allowsClasspathAnnotation, "javax.annotation.Nullable"))) {
            __.dl();__.out("@javax.annotation.Nullable ");
            
          }
          __.dl();
        }
        $(__, a.getWrappedElementType());
        __.out(" ");
        $(__, a.name());
        __.out("Value = ");
        $(__, readParcel, a);
        __.out(";").ln();
        __.out("if (");
        $(__, a.name());
        __.out("Value != null) {").ln();
        __.out("  builder.");
        $(__, a.names.init);
        __.out("(");
        $(__, a.name());
        __.out("Value);").ln();
        __.out("}").ln();
        __.out("  ");
        } else if ($if(a.isNullable())) {
        __.dl();__.dl();__.ln();
        __.out("builder.");
        $(__, a.names.init);
        __.out("(");
        $(__, readParcel, a);
        __.out(");").ln();
        __.out("  ");
        } else if ($if(a.isCollectionType())) {
        __.dl();__.ln();
        __.out("builder.");
        $(__, a.names.addAll());
        __.out("(");
        $(__, readParcel, a);
        __.out(");").ln();
        __.out("  ");
        } else if ($if(a.isMapType())) {
        __.dl();__.ln();
        __.out("builder.");
        $(__, a.names.putAll());
        __.out("(");
        $(__, readParcel, a);
        __.out(");").ln();
        __.out("  ");
        
      } else {
        __.dl();__.ln();
        __.out("builder.");
        $(__, a.names.init);
        __.out("(");
        $(__, readParcel, a);
        __.out(");").ln();
        __.out("  ");
        __.dl();__.ln();
        __.out("  ");
        
      }
      __.dl();__.ln();
      __.dl();_it1.index++;
      _it1.first = false;
    }}
    __.dl();__.ln();
    __.out("return builder.");
    $(__, type.names().build);
    __.out("();").ln();
    
  } else {
    __.dl();__.ln();
    __.out("return ");
    $(__, type.factoryOf().relative());
    __.out("(");
    {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
    for (final org.immutables.value.processor.meta.ValueAttribute c : $in(type.getConstructorArguments())) {
    __.dl();__.dl();
      if ($if($(not, _it1.first))) {
        __.dl();__.out(", ");
        
      }
      __.dl();$(__, readParcel, c);
      __.dl();_it1.index++;
      _it1.first = false;
    }}
    __.dl();__.out(")");
    {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
    for (final org.immutables.value.processor.meta.ValueAttribute a : $in(type.getWithSettableAfterConstruction())) {
    __.dl();__.ln();
      __.out("    .");
      $(__, a.names.with);
      __.out("(");
      $(__, readParcel, a);
      __.out(")");
      __.dl();_it1.index++;
      _it1.first = false;
    }}
    __.dl();__.out(";").ln();
    
  }
  __.dl();__.ln();
  __.dl();
};

org.immutables.generator.Templates.Invokable castBuildStagedBuilder() { return castBuildStagedBuilder; }
private final org.immutables.generator.Templates.Invokable castBuildStagedBuilder = new FragmentDispatch(2, 5);
void _t5__castBuildStagedBuilder(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueType type = $cast(__.param(0));
  final java.lang.String expression = __.param(1).toString();
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  final org.immutables.value.processor.meta.TelescopicBuild tb = $cast(type.getTelescopicBuild());
  __.dl();__.dl();
    if ($if(tb)) {
      __.dl();__.out("((");
      $(__, type.typeBuilderImpl().relative());
      __.out(") ");
      $(__, expression);
      __.out(")");
      
    } else {
      __.dl();$(__, expression);
      
    }
    __.dl();__.dl();_it1.index++;
    _it1.first = false;
  }
  __.dl();__.dl();
};

org.immutables.generator.Templates.Invokable atNullable() { return atNullable; }
private final org.immutables.generator.Templates.Invokable atNullable = new FragmentDispatch(1, 6);
void _t6__atNullable(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueType type = $cast(__.param(0));
  __.dl();
  if ($if($(type, allowsClasspathAnnotation, "javax.annotation.Nullable"))) {
    __.dl();__.out("@javax.annotation.Nullable ");
    
  }
  __.dl();__.dl();
};
private class FragmentDispatch extends org.immutables.generator.Templates.Fragment{
private final int index;
FragmentDispatch(int arity, int index){
super(arity);
this.index = index;
}
@Override public void run(org.immutables.generator.Templates.Invokation invokation){
  switch (index){
  case 0: _t0__generate(invokation); break;
  case 1: _t1__generateCreator(invokation); break;
  case 2: _t2__generateParcelableMethods(invokation); break;
  case 3: _t3__readParcel(invokation); break;
  case 4: _t4__generateParcelableBuild(invokation); break;
  case 5: _t5__castBuildStagedBuilder(invokation); break;
  case 6: _t6__atNullable(invokation); break;
  default: break;
}}}

}

==> value-2.11.0-beta1-sources.jar: org/immutables/value/internal/$processor$/$Generator_Parcelables.java <==
package org.immutables.value.processor;

import static org.immutables.generator.Intrinsics.*;

@java.lang.SuppressWarnings("all")
public class Generator_Parcelables extends org.immutables.value.processor.Parcelables {
public org.immutables.generator.Templates.Invokable generate() { return generate; }
private final org.immutables.generator.Templates.Invokable generate = new FragmentDispatch(1, 0);
void _t0__generate(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueType type = $cast(__.param(0));
  __.ln();
  __.dl();
  if ($if(type.isGenerateParcelable())) {
    __.dl();__.ln();
    __.out("  ");
    $(__, generateCreator, type);
    __.ln();
    __.out("  ");
    $(__, generateParcelableMethods, type);
    __.ln();
    
  }
  __.dl();__.ln();
  __.dl();
};

org.immutables.generator.Templates.Invokable generateCreator() { return generateCreator; }
private final org.immutables.generator.Templates.Invokable generateCreator = new FragmentDispatch(1, 1);
void _t1__generateCreator(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueType type = $cast(__.param(0));
  __.ln();
  __.ln();
  __.out("/** */").ln();
  __.out("public static final android.os.Parcelable.ClassLoaderCreator<");
  $(__, type.typeValue().relative());
  __.out("> CREATOR =").ln();
  __.out("    new android.os.Parcelable.ClassLoaderCreator<");
  $(__, type.typeValue().relative());
  __.out(">() {").ln();
  __.out("      public ");
  $(__, type.typeValue().relative());
  __.out(" createFromParcel(android.os.Parcel in) {").ln();
  __.out("        return createFromParcel(in, this.getClass().getClassLoader());").ln();
  __.out("      }").ln();
  __.ln();
  __.out("      @SuppressWarnings(\"unchecked\") ");
  __.dl();__.ln();
  __.out("      public ");
  $(__, type.typeValue().relative());
  __.out(" createFromParcel(android.os.Parcel in, ClassLoader classLoader) {").ln();
  __.out("        ");
  $(__, generateParcelableBuild, type);
  __.ln();
  __.out("      }").ln();
  __.ln();
  __.out("      public ");
  $(__, type.typeValue().relative());
  $(__, "[]");
  __.out(" newArray(int size) {").ln();
  __.out("        return new ");
  $(__, type.typeValue().relative());
  $(__, "[size]");
  __.out(";").ln();
  __.out("      }").ln();
  __.out("    };").ln();
  __.dl();
};

org.immutables.generator.Templates.Invokable generateParcelableMethods() { return generateParcelableMethods; }
private final org.immutables.generator.Templates.Invokable generateParcelableMethods = new FragmentDispatch(1, 2);
void _t2__generateParcelableMethods(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueType type = $cast(__.param(0));
  __.ln();
  __.ln();
  __.out("/** */").ln();
  __.out("@Override").ln();
  __.out("public int describeContents() {").ln();
  __.out("  return 0; //??").ln();
  __.out("}").ln();
  __.ln();
  __.out("/** */").ln();
  __.out("@Override").ln();
  __.out("public void writeToParcel(android.os.Parcel out, int flags) {").ln();
  __.dl();__.ln();
  __.out("  ");
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  for (final org.immutables.value.processor.meta.ValueAttribute a : $in(type.getSettableAttributes())) {
  __.dl();__.ln();
    __.dl();
    if ($if(a.isEncoding())) {
      __.dl();__.ln();
      __.out("  out.writeValue(");
      $(__, a.names.get);
      __.out("());").ln();
      } else if ($if(a.isJdkOptional())) {
      __.dl();__.ln();
      __.out("  out.writeValue(this.");
      $(__, a.name());
      __.out(");").ln();
      } else if ($if(a.isArrayType())) {
      __.dl();__.ln();
      __.out("  ");
      __.dl();
      if ($if(a.isPrimitiveElement())) {
        __.dl();__.ln();
        __.out("    ");
        __.dl();
        if ($if($(a.getElementType(), eq, "short"))) {
          __.dl();__.ln();
          __.out("  // Do something with short arrays, just for completeness").ln();
          __.out("  // copy it as int array, I dunno").ln();
          __.out("    ");
          
        } else {
          __.dl();__.ln();
          __.out("  out.write");
          $(__, toUpper, a.getElementType());
          __.out("Array(this.");
          $(__, a.name());
          __.out(");").ln();
          __.out("    ");
          
        }
        __.dl();__.ln();
        __.out("  ");
        } else if ($if($(a.getElementType(), eq, "java.lang.String"))) {
        __.dl();__.ln();
        __.out("  out.writeStringArray(this.");
        $(__, a.name());
        __.out(");").ln();
        __.out("  ");
        
      } else {
        __.dl();__.ln();
        __.out("  out.writeArray(this.");
        $(__, a.name());
        __.out(");").ln();
        __.out("  ");
        
      }
      __.dl();__.ln();
      } else if ($if(a.isStringType())) {
      __.dl();__.ln();
      __.out("  out.writeString(this.");
      $(__, a.name());
      __.out(");").ln();
      } else if ($if(a.isBoolean())) {
      __.dl();__.ln();
      __.out("  out.writeByte(this.");
      $(__, a.name());
      __.out(" ? (byte) 1 : (byte) 0);").ln();
      } else if ($if($(a.isShort(), or, a.isChar()))) {
      __.dl();__.ln();
      __.out("  out.writeInt(this.");
      $(__, a.name());
      __.out(");").ln();
      } else if ($if(a.isPrimitive())) {
      __.dl();__.ln();
      __.out("  out.write");
      $(__, toUpper, a.getType());
      __.out("(this.");
      $(__, a.name());
      __.out(");").ln();
      
    } else {
      __.dl();__.ln();
      __.out("  out.writeValue(");
      $(__, a.names.get);
      __.out("());").ln();
      __.dl();__.ln();
      
    }
    __.dl();__.ln();
    __.out("  ");
    __.dl();_it1.index++;
    _it1.first = false;
  }}
  __.dl();__.ln();
  __.out("}").ln();
  __.dl();
};

org.immutables.generator.Templates.Invokable readParcel() { return readParcel; }
private final org.immutables.generator.Templates.Invokable readParcel = new FragmentDispatch(1, 3);
void _t3__readParcel(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueAttribute a = $cast(__.param(0));
  $(__, output.trim, new org.immutables.generator.Templates.Fragment(0) {
  @Override public void run(org.immutables.generator.Templates.Invokation __) {
    __.dl();__.dl();__.ln();
    __.dl();
    if ($if(a.isEncoding())) {
      __.dl();__.ln();
      __.out("  (");
      $(__, a.getType());
      __.out(") in.readValue(classLoader)").ln();
      } else if ($if(a.isJdkOptional())) {
      __.dl();__.ln();
      __.out("  (");
      $(__, a.getWrappedElementType());
      __.out(") in.readValue(classLoader)").ln();
      } else if ($if(a.isNullable())) {
      __.dl();__.ln();
      __.out("  (");
      $(__, a.getType());
      __.out(") in.readValue(classLoader)").ln();
      } else if ($if(a.isArrayType())) {
      __.dl();__.ln();
      __.out("  ");
      __.dl();
      if ($if(a.isPrimitiveElement())) {
        __.dl();__.ln();
        __.out("    ");
        __.dl();
        if ($if($(a.getElementType(), eq, "short"))) {
          __.dl();__.ln();
          __.out("  null/* FIXME: Do something with short arrays */   ");
          __.dl();__.ln();
          __.out("    ");
          
        } else {
          __.dl();__.ln();
          __.out("      in.create");
          $(__, toUpper, a.getElementType());
          __.out("Array()").ln();
          __.out("    ");
          
        }
        __.dl();__.ln();
        __.out("  ");
        } else if ($if($(a.getElementType(), eq, "java.lang.String"))) {
        __.dl();__.ln();
        __.out("  in.createStringArray()").ln();
        __.out("  ");
        
      } else {
        __.dl();__.ln();
        __.out("  (");
        $(__, a.getType());
        __.out(") in.readArray(classLoader)").ln();
        __.out("  ");
        
      }
      __.dl();__.ln();
      } else if ($if(a.isStringType())) {
      __.dl();__.ln();
      __.out("  in.readString()").ln();
      } else if ($if(a.isBoolean())) {
      __.dl();__.ln();
      __.out("  in.readByte() != 0").ln();
      } else if ($if($(a.isShort(), or, a.isChar()))) {
      __.dl();__.ln();
      __.out("  (");
      $(__, a.getType());
      __.out(") in.readInt()").ln();
      } else if ($if(a.isPrimitive())) {
      __.dl();__.ln();
      __.out("  in.read");
      $(__, toUpper, a.getType());
      __.out("()").ln();
      
    } else {
      __.dl();__.ln();
      __.out("  null /* FIXME: read objects and complex types */").ln();
      __.out("  ");
      __.dl();__.ln();
      
    }
    __.dl();__.ln();
    __.dl();
  }});
  __.dl();
};

org.immutables.generator.Templates.Invokable generateParcelableBuild() { return generateParcelableBuild; }
private final org.immutables.generator.Templates.Invokable generateParcelableBuild = new FragmentDispatch(1, 4);
void _t4__generateParcelableBuild(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueType type = $cast(__.param(0));
  __.ln();
  __.dl();
  if ($if(type.isUseBuilder())) {
    __.dl();__.ln();
    $(__, type.typeBuilder().relative());
    __.out(" builder = ");
    $(__, castBuildStagedBuilder, type, new org.immutables.generator.Templates.Fragment(0) {
    @Override public void run(org.immutables.generator.Templates.Invokation __) {
      __.dl();$(__, type.factoryBuilder().relative());
      __.out("()");
      __.dl();
    }});
    __.out(";").ln();
    {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
    for (final org.immutables.value.processor.meta.ValueAttribute a : $in(type.getSettableAttributes())) {
    __.dl();__.ln();
      __.out("  ");
      __.dl();
      if ($if(a.isEncoding())) {
        __.dl();__.ln();
        __.out("builder.");
        $(__, renderers.builderCopyFrom(), a);
        __.out("(");
        $(__, readParcel, a);
        __.out(");").ln();
        __.out("  ");
        } else if ($if(a.isJdkOptional())) {
        __.dl();__.ln();
        {final org.immutables.value.processor.meta.HasStyleInfo s_atNullable_1870265247 = $cast(type);
        $(__, atFallbackNullable, s_atNullable_1870265247);
          
        }
        $(__, a.getWrappedElementType());
        __.out(" ");
        $(__, a.name());
        __.out("Value = ");
        $(__, readParcel, a);
        __.out(";").ln();
        __.out("if (");
        $(__, a.name());
        __.out("Value != null) {").ln();
        __.out("  builder.");
        $(__, a.names.init);
        __.out("(");
        $(__, a.name());
        __.out("Value);").ln();
        __.out("}").ln();
        __.out("  ");
        } else if ($if(a.isNullable())) {
        __.dl();__.dl();__.ln();
        __.out("builder.");
        $(__, a.names.init);
        __.out("(");
        $(__, readParcel, a);
        __.out(");").ln();
        __.out("  ");
        } else if ($if(a.isCollectionType())) {
        __.dl();__.ln();
        __.out("builder.");
        $(__, a.names.addAll());
        __.out("(");
        $(__, readParcel, a);
        __.out(");").ln();
        __.out("  ");
        } else if ($if(a.isMapType())) {
        __.dl();__.ln();
        __.out("builder.");
        $(__, a.names.putAll());
        __.out("(");
        $(__, readParcel, a);
        __.out(");").ln();
        __.out("  ");
        
      } else {
        __.dl();__.ln();
        __.out("builder.");
        $(__, a.names.init);
        __.out("(");
        $(__, readParcel, a);
        __.out(");").ln();
        __.out("  ");
        __.dl();__.ln();
        __.out("  ");
        
      }
      __.dl();__.ln();
      __.dl();_it1.index++;
      _it1.first = false;
    }}
    __.dl();__.ln();
    __.out("return builder.");
    $(__, type.names().build);
    __.out("();").ln();
    
  } else {
    __.dl();__.ln();
    __.out("return ");
    $(__, type.factoryOf().relative());
    __.out("(");
    {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
    for (final org.immutables.value.processor.meta.ValueAttribute c : $in(type.getConstructorArguments())) {
    __.dl();__.dl();
      if ($if($(not, _it1.first))) {
        __.dl();__.out(", ");
        
      }
      __.dl();$(__, readParcel, c);
      __.dl();_it1.index++;
      _it1.first = false;
    }}
    __.dl();__.out(")");
    {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
    for (final org.immutables.value.processor.meta.ValueAttribute a : $in(type.getWithSettableAfterConstruction())) {
    __.dl();__.ln();
      __.out("    .");
      $(__, a.names.with);
      __.out("(");
      $(__, readParcel, a);
      __.out(")");
      __.dl();_it1.index++;
      _it1.first = false;
    }}
    __.dl();__.out(";").ln();
    
  }
  __.dl();__.ln();
  __.dl();
};

org.immutables.generator.Templates.Invokable castBuildStagedBuilder() { return castBuildStagedBuilder; }
private final org.immutables.generator.Templates.Invokable castBuildStagedBuilder = new FragmentDispatch(2, 5);
void _t5__castBuildStagedBuilder(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueType type = $cast(__.param(0));
  final java.lang.String expression = __.param(1).toString();
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  final org.immutables.value.processor.meta.TelescopicBuild tb = $cast(type.getTelescopicBuild());
  __.dl();__.dl();
    if ($if(tb)) {
      __.dl();__.out("((");
      $(__, type.typeBuilderImpl().relative());
      __.out(") ");
      $(__, expression);
      __.out(")");
      
    } else {
      __.dl();$(__, expression);
      
    }
    __.dl();__.dl();_it1.index++;
    _it1.first = false;
  }
  __.dl();__.dl();
};

org.immutables.generator.Templates.Invokable atNullable() { return atNullable; }
private final org.immutables.generator.Templates.Invokable atNullable = new FragmentDispatch(1, 6);
void _t6__atNullable(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.HasStyleInfo s = $cast(__.param(0));
  $(__, atFallbackNullable, s);
  __.dl();
};
private class FragmentDispatch extends org.immutables.generator.Templates.Fragment{
private final int index;
FragmentDispatch(int arity, int index){
super(arity);
this.index = index;
}
@Override public void run(org.immutables.generator.Templates.Invokation invokation){
  switch (index){
  case 0: _t0__generate(invokation); break;
  case 1: _t1__generateCreator(invokation); break;
  case 2: _t2__generateParcelableMethods(invokation); break;
  case 3: _t3__readParcel(invokation); break;
  case 4: _t4__generateParcelableBuild(invokation); break;
  case 5: _t5__castBuildStagedBuilder(invokation); break;
  case 6: _t6__atNullable(invokation); break;
  default: break;
}}}

}
